==> aruba-central-migrate-pkg-1.0.3.tar.gz: aruba-central-migrate-pkg-1.0.3/setup.py <==
"""A setuptools based setup module.

See:
https://packaging.python.org/guides/distributing-packages-using-setuptools/
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

# Get the long description from the README file
long_description = (here / "README.md").read_text(encoding="utf-8")

# Arguments marked as "Required" below must be included for upload to PyPI.
# Fields marked as "Optional" may be commented out.

setup(
    # This is the name of your project. The first time you publish this
    # package, this name will be registered for you. It will determine how
    # users can install this project, e.g.:
    #
    # $ pip install sampleproject

    name="aruba-central-migrate-pkg",  # Required
    
    version="1.0.3",  # Required
    # This is a one-line description or tagline of what your project does. This
    
    description="A sample Python project",  # Optional
    # This is an optional longer description of your project that represents
    
    long_description=long_description,  # Optional
   
    long_description_content_type="text/markdown",
    
    # url="https://github.com/pypa/sampleproject",  # Optional
    
    author="HTS-automation",  # Optional
    
    author_email="prathibha-k@hpe.com",  # Optional
    
    classifiers=[  # Optional
        # Pick your license as you wish
        "License :: OSI Approved :: MIT License",
        # Specify the Python versions you support here. In particular, ensure
        # that you indicate you support Python 3. These classifiers are *not*
        # checked by 'pip install'. See instead 'python_requires' below.
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3 :: Only",
    ],
   
    package_dir={"": "central"},  # Optional
    
    packages=find_packages(where="central"),  # Required
    
    python_requires=">=3.7, <4",
    
    install_requires=[
        "asyncio==3.4.3"
    ] # Optional

)

==> aruba-central-migrate-pkg-1.0.4.tar.gz: aruba-central-migrate-pkg-1.0.4/setup.py <==
"""A setuptools based setup module.

See:
https://packaging.python.org/guides/distributing-packages-using-setuptools/
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

# Get the long description from the README file
long_description = (here / "README.md").read_text(encoding="utf-8")

# Arguments marked as "Required" below must be included for upload to PyPI.
# Fields marked as "Optional" may be commented out.

setup(
    # This is the name of your project. The first time you publish this
    # package, this name will be registered for you. It will determine how
    # users can install this project, e.g.:
    #
    # $ pip install aruba-central-migrate-pkg

    name="aruba-central-migrate-pkg",  # Required
    
    version="1.0.4",  # Required
    # This is a one-line description or tagline of what your project does. This
    
    description="A sample Python project",  # Optional
    # This is an optional longer description of your project that represents
    
    long_description=long_description,  # Optional
   
    long_description_content_type="text/markdown",
    
    # url="https://github.com/pypa/sampleproject",  # Optional
    
    author="HTS-automation",  # Optional
    
    author_email="prathibha-k@hpe.com",  # Optional
    
    classifiers=[  # Optional
        # Pick your license as you wish
        "License :: OSI Approved :: MIT License",
        # Specify the Python versions you support here. In particular, ensure
        # that you indicate you support Python 3. These classifiers are *not*
        # checked by 'pip install'. See instead 'python_requires' below.
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3 :: Only",
    ],
   
    # package_dir={"": "central"},  # Optional
    
    packages=find_packages(exclude=['docs', 'tests']),  # Required
    
    python_requires=">=3.7, <4",
    
    install_requires=[
        "asyncio==3.4.3",
        "sphinx_rtd_theme==1.0.0"
    ] # Optional

)
